@@ -4,7 +4,10 @@ mod use_effect_once;
 mod use_interval;
 mod use_is_first_mount;
 mod use_is_mounted;
+mod use_latest;
+mod use_local_storage;
 mod use_mount;
+mod use_session_storage;
 mod use_timeout;
 mod use_title;
 mod use_toggle;
@@ -17,7 +20,10 @@ pub use use_effect_once::*;
 pub use use_interval::*;
 pub use use_is_first_mount::*;
 pub use use_is_mounted::*;
+pub use use_latest::*;
+pub use use_local_storage::*;
 pub use use_mount::*;
+pub use use_session_storage::*;
 pub use use_timeout::*;
 pub use use_title::*;
 pub use use_toggle::*;
