@@ -2,7 +2,7 @@ use std::fmt;
 use std::ops::Deref;
 use std::rc::Rc;
 
-use yew::functional::{use_reducer, Reducible, UseReducerHandle};
+use yew::prelude::*;
 
 enum CounterAction {
     Increase,
@@ -51,26 +51,32 @@ pub struct UseCounterHandle {
 }
 
 impl UseCounterHandle {
+    /// Increase by `1`.
     pub fn increase(&self) {
         self.inner.dispatch(CounterAction::Increase)
     }
 
+    /// Increase by `delta`.
     pub fn increase_by(&self, delta: i32) {
         self.inner.dispatch(CounterAction::IncreaseBy(delta))
     }
 
+    /// Decrease by `1`.
     pub fn decrease(&self) {
         self.inner.dispatch(CounterAction::Decrease)
     }
 
+    /// Decrease by `delta`.
     pub fn decrease_by(&self, delta: i32) {
         self.inner.dispatch(CounterAction::DecreaseBy(delta))
     }
 
+    /// Set to `value`.
     pub fn set(&self, value: i32) {
         self.inner.dispatch(CounterAction::Set(value))
     }
 
+    /// Reset to initial value.
     pub fn reset(&self) {
         self.inner.dispatch(CounterAction::Reset)
     }
